<template>
  <div class="app-container">
     <el-row :gutter="20">
       <el-col :span="showMap ? 12 : 24" :xs="24">
        <AppTable ref="AppTable" selection :showDeptSearch="false" :url="'tower/point/list'" :tableColumns="tableColumns"
          :tableFilter="tableFilter">
          <template #operatorBox="{ row }">
            <el-button type="primary" plain icon="el-icon-plus" size="mini"
              @click="handleAdd">新增模板</el-button>
          </template>
          <template #operator="{ row }">
            <el-button size="mini" type="text" icon="el-icon-view"
              @click="preview(row)">预览</el-button>
            <el-button size="mini" type="text" icon="el-icon-delete"
              @click="handleDelete(row)">删除</el-button>
          </template>
        </AppTable>
      </el-col>
       <el-col :span="12" :xs="24" v-if="showMap">
          <CesiumMap ></CesiumMap>
       </el-col>
     </el-row>
    
    <shootPointDialog  @on-submit="$refs.AppTable.getData()"  v-if="showDialog" @close="close" :templateId="templateId"></shootPointDialog>
  </div>
</template>

<script>
import shootPointDialog from './components/shootPointDialog.vue';
import CesiumMap from "../../../utils/components/cesium-map.vue";
export default {
  name: "towers",
  dicts: ['model_typpe'],
  components: {
    shootPointDialog,
    CesiumMap
  },
  data() {
    return {
      // 选中数组
      ids: [],
      // 非单个禁用
      single: true,
      // 非多个禁用
      multiple: true,
      tableColumns: [
        {
          label: '模板名称',
          prop: 'templateName'
        },
        {
          label: '模型ID',
          prop: 'modelId'
        },
        {
          label: '操作',
          type: 'slot',
          slotName: 'operator',
          width: '330px'
        },
      ],
      tableFilter: [
        {
          title: '模型名称',
          placeholder: '请输入模型名称',
          fieldName: 'name',
          clearable: true,
          type: 'search',
        }
      ],
      showMap:false,
      showDialog:false,
      templateId:null
    };
  },
  watch: {
  },
  created() {
  },
  mounted() {
  },
  methods: {
    // 添加数据
    handleAdd() {
      this.templateId = null
      this.showMap  = false
      this.showDialog = true
      // this.$refs.shootPointDialog.show()
    },
    // 更新数据
    handleUpdate(row) {
      const ids = row.id || this.ids
      this.$refs.shootPointDialog.show(ids)
    },
    // 删除数据
    handleDelete(row) {
      const ids = row.id || this.ids
      // const name = row.name || ''
      const name = ids
      this.$api.deleteByName('/tower/point', ids,name).then(res => {
        this.$refs.AppTable.getData()
      })
    },
    // 导出表格数据
    handleExport() {
      this.$refs.AppTable.exportExcel()
    },
    // clickRow(row){
    //   console.log(row)
    //   this.showMap =true
    // },
    close(){
      this.showDialog =false
    },
    preview(row){
      console.log(row)
      this.templateId = row.id
      this.showDialog = true
    }
  },
};
</script>

<style scoped>
.left-card {
  height: calc(100vh - 105px);
  overflow: auto;
}

.right-card {
  height: calc(100vh - 105px);
}
</style>
